" Name:         novum
" Description:  port of nvim dev_theme
" Author:       Charan Mandati <charancuz008@gmail.com>
" License:      Vim License (see `:help license`)`
" Last Change:  2026 Jun 17

" Generated by Colortemplate v3.0.0-rc1

hi clear
let g:colors_name = 'novum'

let s:t_Co = has('gui_running') ? 16777216 : str2nr(&t_Co)
let s:tgc = has('termguicolors') && &termguicolors

hi! link Boolean Constant
hi! link Character Constant
hi! link Conditional Statement
hi! link CursorIM Cursor
hi! link CursorLineFold SignColumn
hi! link CursorLineSign SignColumn
hi! link Debug Special
hi! link Define PreProc
hi! link EndOfBuffer NonText
hi! link Exception Statement
hi! link Float Constant
hi! link FoldColumn SignColumn
hi! link Ignore Normal
hi! link IncSearch CurSearch
hi! link Include PreProc
hi! link Keyword Statement
hi! link Label Statement
hi! link LineNrAbove LineNr
hi! link LineNrBelow LineNr
hi! link Macro PreProc
hi! link Number Constant
hi! link PmenuExtra Pmenu
hi! link PmenuExtraSel PmenuSel
hi! link PmenuKind Pmenu
hi! link PmenuKindSel PmenuSel
hi! link PmenuSbar Pmenu
hi! link PopupNotification Normal
hi! link PreCondit PreProc
hi! link PreInsert Added
hi! link Repeat Statement
hi! link SpecialChar Special
hi! link SpecialComment Special
hi! link StatusLineTerm StatusLine
hi! link StatusLineTermNC StatusLineNC
hi! link StorageClass Type
hi! link Structure Type
hi! link TabLine StatusLineNC
hi! link TabLineFill StatusLineNC
hi! link Tag Special
hi! link Terminal Normal
hi! link Typedef Type
hi! link VertSplit Normal
hi! link VisualNOS Visual
hi! link WildMenu PmenuSel

if &background == 'dark'
  let g:terminal_ansi_colors = ['#eef1f8', '#ffc0b9', '#b3f6c0', '#fce094', '#a6dbff', '#ff0000', '#8cf8f7', '#9b9ea4', '#2c2e33', '#590008', '#005523', '#6b5300', '#007373', '#4f5258', '#07080d', '#14161b']

  hi Normal guifg=#e0e2ea guibg=#14161b guisp=NONE gui=NONE ctermfg=188 ctermbg=233 cterm=NONE term=NONE
  hi Added guifg=#b3f6c0 guibg=NONE guisp=NONE gui=NONE ctermfg=157 ctermbg=NONE cterm=NONE term=NONE
  hi Changed guifg=#8cf8f7 guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
  hi ColorColumn guifg=NONE guibg=#4f5258 guisp=NONE gui=NONE ctermfg=NONE ctermbg=59 cterm=NONE term=reverse
  hi Comment guifg=#9b9ea4 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=bold
  hi Conceal guifg=#4f5258 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=NONE
  hi Constant guifg=#e0e2ea guibg=NONE guisp=NONE gui=NONE ctermfg=188 ctermbg=NONE cterm=NONE term=NONE
  hi CurSearch guifg=#07080d guibg=#fce094 guisp=NONE gui=NONE ctermfg=232 ctermbg=222 cterm=NONE term=reverse
  hi Cursor guifg=bg guibg=fg guisp=NONE gui=NONE ctermfg=bg ctermbg=fg cterm=NONE term=reverse
  hi CursorColumn guifg=NONE guibg=#2c2e33 guisp=NONE gui=NONE ctermfg=NONE ctermbg=236 cterm=NONE term=NONE
  hi CursorLine guifg=NONE guibg=#37393f guisp=NONE gui=NONE ctermfg=NONE ctermbg=237 cterm=NONE term=underline
  hi CursorLineNr guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi Delimiter guifg=#e0e2ea guibg=NONE guisp=NONE gui=NONE ctermfg=188 ctermbg=NONE cterm=NONE term=NONE
  hi DiffAdd guifg=#eef1f8 guibg=#005523 guisp=NONE gui=NONE ctermfg=231 ctermbg=22 cterm=NONE term=reverse
  hi DiffChange guifg=#eef1f8 guibg=#384851 guisp=NONE gui=NONE ctermfg=231 ctermbg=239 cterm=NONE term=NONE
  hi DiffDelete guifg=#ffc0b9 guibg=NONE guisp=NONE gui=bold ctermfg=217 ctermbg=NONE cterm=bold term=reverse
  hi DiffText guifg=#eef1f8 guibg=#007373 guisp=NONE gui=NONE ctermfg=231 ctermbg=30 cterm=NONE term=reverse
  hi Directory guifg=#8cf8f7 guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
  hi Error guifg=#eef1f8 guibg=#590008 guisp=NONE gui=NONE ctermfg=231 ctermbg=52 cterm=NONE term=bold,reverse
  hi ErrorMsg guifg=#ffc0b9 guibg=NONE guisp=NONE gui=NONE ctermfg=217 ctermbg=NONE cterm=NONE term=bold,reverse
  hi Folded guifg=#9b9ea4 guibg=#07080d guisp=NONE gui=NONE ctermfg=145 ctermbg=232 cterm=NONE term=NONE
  hi Function guifg=#8cf8f7 guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
  hi Identifier guifg=#a6dbff guibg=NONE guisp=NONE gui=NONE ctermfg=153 ctermbg=NONE cterm=NONE term=NONE
  hi LineNr guifg=#4f5258 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=NONE
  hi MatchParen guifg=#ff0000 guibg=NONE guisp=NONE gui=bold ctermfg=196 ctermbg=NONE cterm=bold term=bold,underline
  hi ModeMsg guifg=#b3f6c0 guibg=NONE guisp=NONE gui=NONE ctermfg=157 ctermbg=NONE cterm=NONE term=bold
  hi MoreMsg guifg=#8cf8f7 guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
  hi NonText guifg=#4f5258 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=NONE
  hi Operator guifg=#e0e2ea guibg=NONE guisp=NONE gui=NONE ctermfg=188 ctermbg=NONE cterm=NONE term=NONE
  hi Pmenu guifg=#e0e2ea guibg=#2c2e33 guisp=NONE gui=NONE ctermfg=188 ctermbg=236 cterm=NONE term=reverse
  hi PmenuMatch guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi PmenuMatchSel guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi PmenuSel guifg=NONE guibg=NONE guisp=NONE gui=reverse ctermfg=NONE ctermbg=NONE cterm=reverse term=bold
  hi PmenuThumb guifg=#e0e2ea guibg=#4f5258 guisp=NONE gui=NONE ctermfg=188 ctermbg=59 cterm=NONE term=NONE
  hi PopupTitle guifg=#e0e2ea guibg=#2c2e33 guisp=NONE gui=bold ctermfg=188 ctermbg=236 cterm=bold term=bold
  hi PreProc guifg=#e0e2ea guibg=NONE guisp=NONE gui=NONE ctermfg=188 ctermbg=NONE cterm=NONE term=NONE
  hi Question guifg=#8cf8f7 guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=standout
  hi QuickFixLine guifg=#8cf8f7 guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
  hi Removed guifg=#ffc0b9 guibg=NONE guisp=NONE gui=NONE ctermfg=217 ctermbg=NONE cterm=NONE term=NONE
  hi Search guifg=#eef1f8 guibg=#6b5300 guisp=NONE gui=NONE ctermfg=231 ctermbg=58 cterm=NONE term=reverse
  hi SignColumn guifg=#4f5258 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=reverse
  hi Special guifg=#8cf8f7 guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
  hi SpecialKey guifg=#4f5258 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=bold
  hi SpellBad guifg=NONE guibg=NONE guisp=#ffc0b9 gui=undercurl ctermfg=217 ctermbg=NONE cterm=underline term=underline
  hi SpellCap guifg=NONE guibg=NONE guisp=#fce094 gui=undercurl ctermfg=222 ctermbg=NONE cterm=underline term=underline
  hi SpellLocal guifg=NONE guibg=NONE guisp=#b3f6c0 gui=undercurl ctermfg=157 ctermbg=NONE cterm=underline term=underline
  hi SpellRare guifg=NONE guibg=NONE guisp=#8cf8f7 gui=undercurl ctermfg=123 ctermbg=NONE cterm=underline term=underline
  hi Statement guifg=#e0e2ea guibg=NONE guisp=NONE gui=bold ctermfg=188 ctermbg=NONE cterm=bold term=NONE
  hi StatusLine guifg=#e0e2ea guibg=#4f5258 guisp=NONE gui=NONE ctermfg=188 ctermbg=59 cterm=NONE term=bold,reverse
  hi StatusLineNC guifg=#c4c6cd guibg=#2c2e33 guisp=NONE gui=NONE ctermfg=251 ctermbg=236 cterm=NONE term=bold,underline
  hi String guifg=#b3f6c0 guibg=NONE guisp=NONE gui=NONE ctermfg=157 ctermbg=NONE cterm=NONE term=NONE
  hi TabLineSel guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold,reverse
  hi Title guifg=#e0e2ea guibg=NONE guisp=NONE gui=bold ctermfg=188 ctermbg=NONE cterm=bold term=NONE
  hi TitleBar guifg=#eef1f8 guibg=#4f5258 guisp=NONE gui=NONE ctermfg=231 ctermbg=59 cterm=NONE term=NONE
  hi TitleBarNC guifg=#c4c6cd guibg=#07080d guisp=NONE gui=NONE ctermfg=251 ctermbg=232 cterm=NONE term=NONE
  hi Todo guifg=#e0e2ea guibg=NONE guisp=NONE gui=bold ctermfg=188 ctermbg=NONE cterm=bold term=bold,reverse
  hi ToolbarButton guifg=#9b9ea4 guibg=#07080d guisp=NONE gui=bold ctermfg=145 ctermbg=232 cterm=bold term=bold,reverse
  hi ToolbarLine guifg=NONE guibg=#07080d guisp=NONE gui=NONE ctermfg=NONE ctermbg=232 cterm=NONE term=reverse
  hi Type guifg=#e0e2ea guibg=NONE guisp=NONE gui=NONE ctermfg=188 ctermbg=NONE cterm=NONE term=NONE
  hi Underlined guifg=NONE guibg=NONE guisp=NONE gui=underline ctermfg=NONE ctermbg=NONE cterm=underline term=underline
  hi VertSplitNC guifg=#2c2e33 guibg=NONE guisp=NONE gui=NONE ctermfg=236 ctermbg=NONE cterm=NONE term=NONE
  hi Visual guifg=NONE guibg=#4f5258 guisp=NONE gui=NONE ctermfg=NONE ctermbg=59 cterm=NONE term=reverse
  hi WarningMsg guifg=#fce094 guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=standout
  hi debugBreakpoint guifg=#eef1f8 guibg=#590008 guisp=NONE gui=NONE ctermfg=231 ctermbg=52 cterm=NONE term=NONE
  hi debugPC guifg=#eef1f8 guibg=#007373 guisp=NONE gui=NONE ctermfg=231 ctermbg=30 cterm=NONE term=NONE
  hi lCursor guifg=bg guibg=fg guisp=NONE gui=NONE ctermfg=bg ctermbg=fg cterm=NONE term=NONE

  if s:tgc || s:t_Co >= 256
    finish
  endif

  if s:t_Co >= 16
    hi Normal ctermfg=LightGray ctermbg=Black cterm=NONE
    hi Added ctermfg=LightGreen ctermbg=NONE cterm=NONE
    hi Changed ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=NONE ctermbg=DarkGray cterm=NONE
    hi Comment ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Constant ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=Black ctermbg=Yellow cterm=bold,reverse
    hi Cursor ctermfg=bg ctermbg=fg cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=DarkGray cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=DarkGray cterm=underline
    hi CursorLineNr ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Delimiter ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=White ctermbg=DarkGreen cterm=NONE
    hi DiffChange ctermfg=White ctermbg=LightBlue cterm=NONE
    hi DiffDelete ctermfg=Red ctermbg=NONE cterm=bold
    hi DiffText ctermfg=White ctermbg=DarkCyan cterm=NONE
    hi Directory ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi Error ctermfg=White ctermbg=DarkRed cterm=NONE
    hi ErrorMsg ctermfg=Red ctermbg=NONE cterm=NONE
    hi Folded ctermfg=Black ctermbg=Brown cterm=NONE
    hi Function ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=LightBlue ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=Red ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=LightGreen ctermbg=NONE cterm=NONE
    hi MoreMsg ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi NonText ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Operator ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=LightGray ctermbg=DarkGray cterm=NONE
    hi PmenuMatch ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuSel ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuThumb ctermfg=LightGray ctermbg=DarkGray cterm=NONE
    hi PopupTitle ctermfg=LightGray ctermbg=DarkGray cterm=bold
    hi PreProc ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi Question ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi Removed ctermfg=Red ctermbg=NONE cterm=NONE
    hi Search ctermfg=White ctermbg=DarkRed cterm=NONE
    hi SignColumn ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Special ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=Red ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Yellow ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=LightGreen ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=LightCyan ctermbg=NONE cterm=underline
    hi Statement ctermfg=LightGray ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=LightGray ctermbg=DarkGray cterm=NONE
    hi StatusLineNC ctermfg=LightGray ctermbg=DarkGray cterm=NONE
    hi String ctermfg=LightGreen ctermbg=NONE cterm=NONE
    hi TabLineSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi Title ctermfg=LightGray ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=White ctermbg=DarkGray cterm=NONE
    hi TitleBarNC ctermfg=LightGray ctermbg=Black cterm=NONE
    hi Todo ctermfg=LightGray ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=DarkGray ctermbg=Black cterm=bold
    hi ToolbarLine ctermfg=NONE ctermbg=Black cterm=NONE
    hi Type ctermfg=LightGray ctermbg=NONE cterm=bold
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplitNC ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Visual ctermfg=NONE ctermbg=DarkGray cterm=NONE
    hi WarningMsg ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=White ctermbg=DarkRed cterm=NONE
    hi debugPC ctermfg=White ctermbg=DarkCyan cterm=NONE
    hi lCursor ctermfg=bg ctermbg=fg cterm=NONE
    finish
  endif

  if s:t_Co >= 8
    hi Normal ctermfg=LightGray ctermbg=Black cterm=NONE
    hi Added ctermfg=LightGreen ctermbg=NONE cterm=NONE
    hi Changed ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=NONE ctermbg=Black cterm=NONE
    hi Comment ctermfg=Brown ctermbg=NONE cterm=bold
    hi Conceal ctermfg=Brown ctermbg=NONE cterm=NONE
    hi Constant ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=Black ctermbg=Yellow cterm=NONE
    hi Cursor ctermfg=bg ctermbg=fg cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=NONE ctermbg=NONE cterm=bold
    hi Delimiter ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=White ctermbg=DarkGreen cterm=NONE
    hi DiffChange ctermfg=White ctermbg=LightBlue cterm=NONE
    hi DiffDelete ctermfg=Red ctermbg=NONE cterm=bold
    hi DiffText ctermfg=White ctermbg=DarkCyan cterm=NONE
    hi Directory ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi Error ctermfg=White ctermbg=DarkRed cterm=NONE
    hi ErrorMsg ctermfg=Red ctermbg=NONE cterm=NONE
    hi FoldColumn ctermfg=Brown ctermbg=NONE cterm=NONE
    hi Folded ctermfg=Brown ctermbg=NONE cterm=NONE
    hi Function ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=LightBlue ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=Brown ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=Yellow ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=LightGreen ctermbg=NONE cterm=NONE
    hi MoreMsg ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi NonText ctermfg=Brown ctermbg=NONE cterm=NONE
    hi Operator ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=LightGray ctermbg=DarkGray cterm=NONE
    hi PmenuMatch ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuSel ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuThumb ctermfg=LightGray ctermbg=DarkGray cterm=NONE
    hi PopupTitle ctermfg=LightGray ctermbg=DarkGray cterm=bold
    hi PreProc ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi Question ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi Removed ctermfg=Red ctermbg=NONE cterm=NONE
    hi Search ctermfg=White ctermbg=Brown cterm=NONE
    hi SignColumn ctermfg=Brown ctermbg=NONE cterm=NONE
    hi Special ctermfg=LightCyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=Brown ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=Red ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Yellow ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=LightGreen ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=LightCyan ctermbg=NONE cterm=underline
    hi Statement ctermfg=LightGray ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=NONE ctermbg=NONE cterm=bold,reverse
    hi StatusLineNC ctermfg=NONE ctermbg=NONE cterm=reverse
    hi String ctermfg=LightGreen ctermbg=NONE cterm=NONE
    hi TabLineSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi Title ctermfg=LightGray ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=White ctermbg=DarkGray cterm=NONE
    hi TitleBarNC ctermfg=LightGray ctermbg=Black cterm=NONE
    hi Todo ctermfg=LightGray ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=DarkGray ctermbg=Black cterm=bold
    hi ToolbarLine ctermfg=NONE ctermbg=Black cterm=NONE
    hi Type ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplitNC ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
    hi WarningMsg ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=White ctermbg=DarkRed cterm=NONE
    hi debugPC ctermfg=White ctermbg=DarkCyan cterm=NONE
    hi lCursor ctermfg=bg ctermbg=fg cterm=NONE
    finish
  endif

  if s:t_Co >= 0
    hi CursorIM term=NONE
    hi CursorLineFold term=underline
    hi CursorLineSign term=underline
    hi EndOfBuffer term=NONE
    hi Float term=NONE
    hi FoldColumn term=NONE
    hi Ignore term=NONE
    hi IncSearch term=bold,reverse,underline
    hi Number term=NONE
    hi PmenuSbar term=reverse
    hi StatusLineTerm term=bold,reverse
    hi StatusLineTermNC term=bold,underline
    hi TabLine term=bold,underline
    hi TabLineFill term=NONE
    hi Terminal term=NONE
    hi VertSplit term=NONE
    hi VisualNOS term=NONE
    hi WildMenu term=bold
    finish
  endif

  finish
endif

if &background == 'light'
  let g:terminal_ansi_colors = ['#07080d', '#590008', '#005523', '#6b5300', '#004c73', '#ff0000', '#007373', '#4f5258', '#c4c6cd', '#ffc0b9', '#b3f6c0', '#fce094', '#8cf8f7', '#9b9ea4', '#eef1f8', '#e0e2ea']

  hi Normal guifg=#14161b guibg=#e0e2ea guisp=NONE gui=NONE ctermfg=233 ctermbg=188 cterm=NONE term=NONE
  hi Added guifg=#005523 guibg=NONE guisp=NONE gui=NONE ctermfg=22 ctermbg=NONE cterm=NONE term=NONE
  hi Changed guifg=#007373 guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi ColorColumn guifg=NONE guibg=#9b9ea4 guisp=NONE gui=NONE ctermfg=NONE ctermbg=145 cterm=NONE term=reverse
  hi Comment guifg=#4f5258 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=bold
  hi Conceal guifg=#9b9ea4 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=NONE
  hi Constant guifg=#14161b guibg=NONE guisp=NONE gui=NONE ctermfg=233 ctermbg=NONE cterm=NONE term=NONE
  hi CurSearch guifg=#eef1f8 guibg=#6b5300 guisp=NONE gui=NONE ctermfg=231 ctermbg=58 cterm=NONE term=reverse
  hi Cursor guifg=bg guibg=fg guisp=NONE gui=NONE ctermfg=bg ctermbg=fg cterm=NONE term=reverse
  hi CursorColumn guifg=NONE guibg=#c4c6cd guisp=NONE gui=NONE ctermfg=NONE ctermbg=251 cterm=NONE term=NONE
  hi CursorLine guifg=NONE guibg=#d4d6dd guisp=NONE gui=NONE ctermfg=NONE ctermbg=254 cterm=NONE term=underline
  hi CursorLineNr guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi Delimiter guifg=#14161b guibg=NONE guisp=NONE gui=NONE ctermfg=233 ctermbg=NONE cterm=NONE term=NONE
  hi DiffAdd guifg=#07080d guibg=#b3f6c0 guisp=NONE gui=NONE ctermfg=232 ctermbg=157 cterm=NONE term=reverse
  hi DiffChange guifg=#07080d guibg=#b8cfc7 guisp=NONE gui=NONE ctermfg=232 ctermbg=152 cterm=NONE term=NONE
  hi DiffDelete guifg=#590008 guibg=NONE guisp=NONE gui=bold ctermfg=52 ctermbg=NONE cterm=bold term=reverse
  hi DiffText guifg=#07080d guibg=#8cf8f7 guisp=NONE gui=NONE ctermfg=232 ctermbg=30 cterm=NONE term=reverse
  hi Directory guifg=#007373 guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi Error guifg=#07080d guibg=#ffc0b9 guisp=NONE gui=NONE ctermfg=232 ctermbg=217 cterm=NONE term=bold,reverse
  hi ErrorMsg guifg=#590008 guibg=NONE guisp=NONE gui=NONE ctermfg=52 ctermbg=NONE cterm=NONE term=bold,reverse
  hi Folded guifg=#4f5258 guibg=#eef1f8 guisp=NONE gui=NONE ctermfg=59 ctermbg=231 cterm=NONE term=NONE
  hi Function guifg=#007373 guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi Identifier guifg=#004c73 guibg=NONE guisp=NONE gui=NONE ctermfg=24 ctermbg=NONE cterm=NONE term=NONE
  hi LineNr guifg=#9b9ea4 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=NONE
  hi MatchParen guifg=#ff0000 guibg=NONE guisp=NONE gui=bold ctermfg=196 ctermbg=NONE cterm=bold term=bold,underline
  hi ModeMsg guifg=#005523 guibg=NONE guisp=NONE gui=NONE ctermfg=22 ctermbg=NONE cterm=NONE term=bold
  hi MoreMsg guifg=#007373 guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi NonText guifg=#9b9ea4 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=NONE
  hi Operator guifg=#14161b guibg=NONE guisp=NONE gui=NONE ctermfg=233 ctermbg=NONE cterm=NONE term=NONE
  hi Pmenu guifg=#14161b guibg=#c4c6cd guisp=NONE gui=NONE ctermfg=233 ctermbg=251 cterm=NONE term=reverse
  hi PmenuMatch guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi PmenuMatchSel guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi PmenuSel guifg=NONE guibg=NONE guisp=NONE gui=reverse ctermfg=NONE ctermbg=NONE cterm=reverse term=bold
  hi PmenuThumb guifg=#14161b guibg=#9b9ea4 guisp=NONE gui=NONE ctermfg=233 ctermbg=145 cterm=NONE term=NONE
  hi PopupTitle guifg=#14161b guibg=#c4c6cd guisp=NONE gui=bold ctermfg=233 ctermbg=251 cterm=bold term=bold
  hi PreProc guifg=#14161b guibg=NONE guisp=NONE gui=NONE ctermfg=233 ctermbg=NONE cterm=NONE term=NONE
  hi Question guifg=#007373 guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=standout
  hi QuickFixLine guifg=#007373 guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi Removed guifg=#590008 guibg=NONE guisp=NONE gui=NONE ctermfg=52 ctermbg=NONE cterm=NONE term=NONE
  hi Search guifg=#07080d guibg=#fce094 guisp=NONE gui=NONE ctermfg=232 ctermbg=222 cterm=NONE term=reverse
  hi SignColumn guifg=#9b9ea4 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=reverse
  hi Special guifg=#007373 guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi SpecialKey guifg=#9b9ea4 guibg=NONE guisp=NONE gui=NONE ctermfg=145 ctermbg=NONE cterm=NONE term=bold
  hi SpellBad guifg=NONE guibg=NONE guisp=#590008 gui=undercurl ctermfg=52 ctermbg=NONE cterm=underline term=underline
  hi SpellCap guifg=NONE guibg=NONE guisp=#6b5300 gui=undercurl ctermfg=58 ctermbg=NONE cterm=underline term=underline
  hi SpellLocal guifg=NONE guibg=NONE guisp=#005523 gui=undercurl ctermfg=22 ctermbg=NONE cterm=underline term=underline
  hi SpellRare guifg=NONE guibg=NONE guisp=#007373 gui=undercurl ctermfg=23 ctermbg=NONE cterm=underline term=underline
  hi Statement guifg=#14161b guibg=NONE guisp=NONE gui=bold ctermfg=233 ctermbg=NONE cterm=bold term=NONE
  hi StatusLine guifg=#14161b guibg=#9b9ea4 guisp=NONE gui=NONE ctermfg=233 ctermbg=145 cterm=NONE term=bold,reverse
  hi StatusLineNC guifg=#2c2e33 guibg=#c4c6cd guisp=NONE gui=NONE ctermfg=236 ctermbg=251 cterm=NONE term=bold,underline
  hi String guifg=#005523 guibg=NONE guisp=NONE gui=NONE ctermfg=22 ctermbg=NONE cterm=NONE term=NONE
  hi TabLineSel guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold,reverse
  hi Title guifg=#14161b guibg=NONE guisp=NONE gui=bold ctermfg=233 ctermbg=NONE cterm=bold term=NONE
  hi TitleBar guifg=#2c2e33 guibg=#eef1f8 guisp=NONE gui=NONE ctermfg=236 ctermbg=231 cterm=NONE term=NONE
  hi TitleBarNC guifg=#07080d guibg=#9b9ea4 guisp=NONE gui=NONE ctermfg=232 ctermbg=145 cterm=NONE term=NONE
  hi Todo guifg=#14161b guibg=NONE guisp=NONE gui=bold ctermfg=233 ctermbg=NONE cterm=bold term=bold,reverse
  hi ToolbarButton guifg=#4f5258 guibg=#eef1f8 guisp=NONE gui=bold ctermfg=59 ctermbg=231 cterm=bold term=bold,reverse
  hi ToolbarLine guifg=NONE guibg=#eef1f8 guisp=NONE gui=NONE ctermfg=NONE ctermbg=231 cterm=NONE term=reverse
  hi Type guifg=#14161b guibg=NONE guisp=NONE gui=NONE ctermfg=233 ctermbg=NONE cterm=NONE term=NONE
  hi Underlined guifg=NONE guibg=NONE guisp=NONE gui=underline ctermfg=NONE ctermbg=NONE cterm=underline term=underline
  hi VertSplitNC guifg=#c4c6cd guibg=NONE guisp=NONE gui=NONE ctermfg=251 ctermbg=NONE cterm=NONE term=NONE
  hi Visual guifg=NONE guibg=#9b9ea4 guisp=NONE gui=NONE ctermfg=NONE ctermbg=145 cterm=NONE term=reverse
  hi WarningMsg guifg=#6b5300 guibg=NONE guisp=NONE gui=NONE ctermfg=58 ctermbg=NONE cterm=NONE term=standout
  hi debugBreakpoint guifg=#07080d guibg=#ffc0b9 guisp=NONE gui=NONE ctermfg=232 ctermbg=217 cterm=NONE term=NONE
  hi debugPC guifg=#07080d guibg=#8cf8f7 guisp=NONE gui=NONE ctermfg=232 ctermbg=30 cterm=NONE term=NONE
  hi lCursor guifg=bg guibg=fg guisp=NONE gui=NONE ctermfg=bg ctermbg=fg cterm=NONE term=NONE

  if s:tgc || s:t_Co >= 256
    finish
  endif

  if s:t_Co >= 16
    hi Normal ctermfg=Black ctermbg=LightGray cterm=NONE
    hi Added ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi Changed ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=NONE ctermbg=DarkGray cterm=NONE
    hi Comment ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Constant ctermfg=Black ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=White ctermbg=Brown cterm=bold,reverse
    hi Cursor ctermfg=bg ctermbg=fg cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=LightGray cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=LightGray cterm=underline
    hi CursorLineNr ctermfg=Brown ctermbg=NONE cterm=NONE
    hi Delimiter ctermfg=Black ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=Black ctermbg=LightGreen cterm=NONE
    hi DiffChange ctermfg=Black ctermbg=LightGreen cterm=NONE
    hi DiffDelete ctermfg=DarkRed ctermbg=NONE cterm=bold
    hi DiffText ctermfg=Black ctermbg=LightCyan cterm=NONE
    hi Directory ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Error ctermfg=Black ctermbg=LightRed cterm=NONE
    hi ErrorMsg ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi Folded ctermfg=White ctermbg=Yellow cterm=NONE
    hi Function ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=DarkBlue ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=Red ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi MoreMsg ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi NonText ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Operator ctermfg=Black ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=Black ctermbg=LightGray cterm=NONE
    hi PmenuMatch ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuSel ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuThumb ctermfg=Black ctermbg=DarkGray cterm=NONE
    hi PopupTitle ctermfg=Black ctermbg=LightGray cterm=bold
    hi PreProc ctermfg=Black ctermbg=NONE cterm=NONE
    hi Question ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Removed ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi Search ctermfg=Black ctermbg=LightRed cterm=NONE
    hi SignColumn ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi Special ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=DarkGray ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=DarkRed ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Brown ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=DarkGreen ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=Cyan ctermbg=NONE cterm=underline
    hi Statement ctermfg=Black ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=Black ctermbg=DarkGray cterm=NONE
    hi StatusLineNC ctermfg=DarkGray ctermbg=LightGray cterm=NONE
    hi String ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi TabLineSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi Title ctermfg=Black ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=DarkGray ctermbg=White cterm=NONE
    hi TitleBarNC ctermfg=Black ctermbg=DarkGray cterm=NONE
    hi Todo ctermfg=Black ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=DarkGray ctermbg=White cterm=bold
    hi ToolbarLine ctermfg=NONE ctermbg=White cterm=NONE
    hi Type ctermfg=Black ctermbg=NONE cterm=bold
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplitNC ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi Visual ctermfg=NONE ctermbg=DarkGray cterm=NONE
    hi WarningMsg ctermfg=Brown ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=Black ctermbg=LightRed cterm=NONE
    hi debugPC ctermfg=Black ctermbg=LightCyan cterm=NONE
    hi lCursor ctermfg=bg ctermbg=fg cterm=NONE
    finish
  endif

  if s:t_Co >= 8
    hi Normal ctermfg=Black ctermbg=LightGray cterm=NONE
    hi Added ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi Changed ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=NONE ctermbg=LightGray cterm=NONE
    hi Comment ctermfg=Yellow ctermbg=NONE cterm=bold
    hi Conceal ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Constant ctermfg=Black ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=White ctermbg=Brown cterm=NONE
    hi Cursor ctermfg=bg ctermbg=fg cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=NONE ctermbg=NONE cterm=bold
    hi Delimiter ctermfg=Black ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=Black ctermbg=LightGreen cterm=NONE
    hi DiffChange ctermfg=Black ctermbg=LightGreen cterm=NONE
    hi DiffDelete ctermfg=DarkRed ctermbg=NONE cterm=bold
    hi DiffText ctermfg=Black ctermbg=LightCyan cterm=NONE
    hi Directory ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Error ctermfg=Black ctermbg=LightRed cterm=NONE
    hi ErrorMsg ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi FoldColumn ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Folded ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Function ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=DarkBlue ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=Brown ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi MoreMsg ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi NonText ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Operator ctermfg=Black ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=Black ctermbg=LightGray cterm=NONE
    hi PmenuMatch ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuSel ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuThumb ctermfg=Black ctermbg=DarkGray cterm=NONE
    hi PopupTitle ctermfg=Black ctermbg=LightGray cterm=bold
    hi PreProc ctermfg=Black ctermbg=NONE cterm=NONE
    hi Question ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Removed ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi Search ctermfg=Black ctermbg=Yellow cterm=NONE
    hi SignColumn ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Special ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=DarkRed ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Brown ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=DarkGreen ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=Cyan ctermbg=NONE cterm=underline
    hi Statement ctermfg=Black ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=NONE ctermbg=NONE cterm=bold,reverse
    hi StatusLineNC ctermfg=NONE ctermbg=NONE cterm=reverse
    hi String ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi TabLineSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi Title ctermfg=Black ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=DarkGray ctermbg=White cterm=NONE
    hi TitleBarNC ctermfg=Black ctermbg=DarkGray cterm=NONE
    hi Todo ctermfg=Black ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=DarkGray ctermbg=White cterm=bold
    hi ToolbarLine ctermfg=NONE ctermbg=White cterm=NONE
    hi Type ctermfg=Black ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplitNC ctermfg=LightGray ctermbg=NONE cterm=NONE
    hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
    hi WarningMsg ctermfg=Brown ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=Black ctermbg=LightRed cterm=NONE
    hi debugPC ctermfg=Black ctermbg=LightCyan cterm=NONE
    hi lCursor ctermfg=bg ctermbg=fg cterm=NONE
    finish
  endif

  if s:t_Co >= 0
    hi CursorIM term=NONE
    hi CursorLineFold term=underline
    hi CursorLineSign term=underline
    hi EndOfBuffer term=NONE
    hi Float term=NONE
    hi FoldColumn term=NONE
    hi Ignore term=NONE
    hi IncSearch term=bold,reverse,underline
    hi Number term=NONE
    hi PmenuSbar term=reverse
    hi StatusLineTerm term=bold,reverse
    hi StatusLineTermNC term=bold,underline
    hi TabLine term=bold,underline
    hi TabLineFill term=NONE
    hi Terminal term=NONE
    hi VertSplit term=NONE
    hi VisualNOS term=NONE
    hi WildMenu term=bold
    finish
  endif

endif

" vim: et ts=8 sw=2 sts=2
